@@ -1021,7 +1021,7 @@ dns_name_toregion(dns_name_t *name, isc_region_t *r) {
 
 isc_result_t
 dns_name_fromtext(dns_name_t *name, isc_buffer_t *source,
-		  dns_name_t *origin, unsigned int options,
+		  const dns_name_t *origin, unsigned int options,
 		  isc_buffer_t *target)
 {
 	unsigned char *ndata, *label = NULL;
@@ -2388,6 +2388,14 @@ dns_name_tostring(dns_name_t *name, char **target, isc_mem_t *mctx) {
 isc_result_t
 dns_name_fromstring(dns_name_t *target, const char *src, unsigned int options,
 		    isc_mem_t *mctx)
+{
+	return (dns_name_fromstring2(target, src, dns_rootname, options, mctx));
+}
+
+isc_result_t
+dns_name_fromstring2(dns_name_t *target, const char *src,
+		     const dns_name_t *origin, unsigned int options,
+		     isc_mem_t *mctx)
 {
 	isc_result_t result;
 	isc_buffer_t buf;
@@ -2405,13 +2413,12 @@ dns_name_fromstring(dns_name_t *target, const char *src, unsigned int options,
 		name = dns_fixedname_name(&fn);
 	}
 
-	result = dns_name_fromtext(name, &buf, dns_rootname, options, NULL);
+	result = dns_name_fromtext(name, &buf, origin, options, NULL);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 
 	if (name != target)
-		result = dns_name_dup(name, mctx, target);
-
+		result = dns_name_dupwithoffsets(name, mctx, target);
 	return (result);
 }
 
